mix feistel_cipher.install (feistel_cipher v1.1.0)

An Ecto migration for Feistel cipher

Example

mix feistel_cipher.install
  • --repo or -r — Specify an Ecto repo for FeistelCipher to use.
  • --functions-prefix or -p — Specify the PostgreSQL schema prefix where the FeistelCipher functions will be created, defaults to public
  • --functions-salt or -s — Specify the constant value used in the Feistel cipher algorithm. A random value is generated by default if not specified. Must be between 0 and 2^31-1.