mix feistel_cipher.install (feistel_cipher v1.1.0)
View SourceAn Ecto migration for Feistel cipher
Example
mix feistel_cipher.install
--repoor-r— Specify an Ecto repo for FeistelCipher to use.--functions-prefixor-p— Specify the PostgreSQL schema prefix where the FeistelCipher functions will be created, defaults topublic--functions-saltor-s— Specify the constant value used in the Feistel cipher algorithm. A random value is generated by default if not specified. Must be between 0 and 2^31-1.