mix feistel_cipher.upgrade (feistel_cipher v1.1.0)
View SourceGenerate a migration to upgrade FeistelCipher from v0.x to v1.0
Generates an Ecto migration that upgrades your database from FeistelCipher v0.x to v1.0.
v1.0 uses new PostgreSQL functions (feistel_cipher_v1, feistel_trigger_v1)
that coexist with the old ones, allowing a smooth upgrade.
Example
mix feistel_cipher.upgrade
Options
--repoor-r— Specify an Ecto repo for FeistelCipher to use.--functions-prefixor-p— Specify the PostgreSQL schema prefix (default:public)